@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::6_0::Async::Bulk;
-$Search::Elasticsearch::Client::6_0::Async::Bulk::VERSION = '6.00';
+$Search::Elasticsearch::Client::6_0::Async::Bulk::VERSION = '6.81';
 use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
@@ -127,7 +127,7 @@ Search::Elasticsearch::Client::6_0::Async::Bulk - A helper module for the Bulk A
 
 =head1 VERSION
 
-version 6.00
+version 6.81
 
 =head1 SYNOPSIS
 
@@ -494,11 +494,11 @@ L<Search::Elasticsearch::Client::6_0::Direct/update()>.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
